import type { AxiosResponse } from "axios";
import { RiotApiService } from "../client/RiotApiService";
export declare namespace AccountV1 {
    interface AccountDto {
        puuid: string;
        /**
         * This field may be excluded from the response if the account doesn't have a gameName.
         */
        gameName?: string;
        /**
         * This field may be excluded from the response if the account doesn't have a tagLine.
         */
        tagLine?: string;
        [key: string]: any;
    }
    interface ActiveShardDto {
        puuid: string;
        game: "val" | "lor";
        activeShard: string;
    }
}
export declare class AccountV1 extends RiotApiService {
    /**
     * Get account by puuid
     */
    byPuuid(puuid: string): Promise<AxiosResponse<AccountV1.AccountDto>>;
    /**
     * Get account by riot id
     */
    byRiotId(gameName: string, tagLine: string): Promise<AxiosResponse<AccountV1.AccountDto>>;
    /**
     * Get active shard for a player
     */
    activeShardsByGameAndPuuid(puuid: string): Promise<AxiosResponse<AccountV1.ActiveShardDto>>;
    /**
     * ! This API service is required your project to be registered by Riot Games.
     *
     * Get account by access token
     * @param authorization (Header Parameters)
     */
    byAccessToken(authorization: string): Promise<AxiosResponse<AccountV1.AccountDto>>;
}
