import type { AxiosResponse } from "axios";
import type { Locale } from "@valapi/lib";
import { RiotApiService } from "../client/RiotApiService";
export declare namespace ContentV1 {
    interface ActDto {
        name: string;
        /**
         * This field is excluded from the response when a locale is set
         */
        localizedNames?: Record<Locale.ID, string>;
        id: string;
        isActive: boolean;
        [key: string]: any;
    }
    interface ContentItemDto {
        name: string;
        /**
         * This field is excluded from the response when a locale is set
         */
        localizedNames?: Record<Locale.ID, string>;
        id: string;
        assetName: string;
        /**
         * This field is only included for maps and game modes. These values are used in the match response.
         */
        assetPath?: string;
        [key: string]: any;
    }
    interface ContentDto {
        version: string;
        characters: Array<ContentV1.ContentItemDto>;
        maps: Array<ContentV1.ContentItemDto>;
        chromas: Array<ContentV1.ContentItemDto>;
        skins: Array<ContentV1.ContentItemDto>;
        skinLevels: Array<ContentV1.ContentItemDto>;
        equips: Array<ContentV1.ContentItemDto>;
        gameModes: Array<ContentV1.ContentItemDto>;
        sprays: Array<ContentV1.ContentItemDto>;
        sprayLevels: Array<ContentV1.ContentItemDto>;
        charms: Array<ContentV1.ContentItemDto>;
        charmLevels: Array<ContentV1.ContentItemDto>;
        playerCards: Array<ContentV1.ContentItemDto>;
        playerTitles: Array<ContentV1.ContentItemDto>;
        acts: Array<ContentV1.ActDto>;
        [key: string]: any;
    }
}
export declare class ContentV1 extends RiotApiService {
    /**
     * Get content optionally filtered by locale
     * @param locale (default: en-US)
     */
    contents(locale?: Locale.ID): Promise<AxiosResponse<ContentV1.ContentDto>>;
}
