import type { AxiosResponse } from "axios";
import type { QueueId } from "@valapi/lib";
import { RiotApiService } from "../client/RiotApiService";
export declare namespace MatchV1 {
    interface MatchInfoDto {
        matchId: string;
        mapId: string;
        gameLengthMillis: number;
        gameStartMillis: number;
        provisioningFlowId: string;
        isCompleted: boolean;
        customGameName: string;
        queueId: string;
        gameMode: string;
        isRanked: boolean;
        seasonId: string;
    }
    interface AbilityCastsDto {
        grenadeCasts: number;
        ability1Casts: number;
        ability2Casts: number;
        ultimateCasts: number;
    }
    interface PlayerStatsDto {
        score: number;
        roundsPlayed: number;
        kills: number;
        deaths: number;
        assists: number;
        playtimeMillis: number;
        abilityCasts: MatchV1.AbilityCastsDto;
    }
    interface PlayerDto {
        puuid: string;
        gameName: string;
        tagLine: string;
        teamId: string;
        partyId: string;
        characterId: string;
        stats: MatchV1.PlayerStatsDto;
        competitiveTier: number;
        playerCard: string;
        playerTitle: string;
    }
    interface CoachDto {
        puuid: string;
        teamId: string;
    }
    interface TeamDto {
        teamId: string;
        won: boolean;
        roundsPlayed: number;
        roundsWon: number;
        numPoints: number;
    }
    interface LocationDto {
        x: number;
        y: number;
    }
    interface PlayerLocationsDto {
        puuid: string;
        viewRadians: number;
        location: MatchV1.LocationDto;
    }
    interface FinishingDamageDto {
        damageType: string;
        damageItem: string;
        isSecondaryFireMode: boolean;
    }
    interface KillDto {
        timeSinceGameStartMillis: number;
        timeSinceRoundStartMillis: number;
        killer: string;
        victim: string;
        victimLocation: MatchV1.LocationDto;
        assistants: Array<string>;
        playerLocations: Array<MatchV1.PlayerLocationsDto>;
        finishingDamage: MatchV1.FinishingDamageDto;
    }
    interface DamageDto {
        receiver: string;
        damage: number;
        legshots: number;
        bodyshots: number;
        headshots: number;
    }
    interface EconomyDto {
        loadoutValue: number;
        weapon: string;
        armor: string;
        remaining: number;
        spent: number;
    }
    interface AbilityDto {
        grenadeEffects: string;
        ability1Effects: string;
        ability2Effects: string;
        ultimateEffects: string;
    }
    interface PlayerRoundStatsDto {
        puuid: string;
        kills: Array<MatchV1.KillDto>;
        damage: Array<MatchV1.DamageDto>;
        score: number;
        economy: MatchV1.EconomyDto;
        ability: MatchV1.AbilityDto;
    }
    interface RoundResultDto {
        roundNum: number;
        roundResult: string;
        roundCeremony: string;
        winningTeam: string;
        bombPlanter: string;
        bombDefuser: string;
        plantRoundTime: number;
        plantPlayerLocations: Array<MatchV1.PlayerLocationsDto>;
        plantLocation: MatchV1.LocationDto;
        plantSite: string;
        defuseRoundTime: number;
        defusePlayerLocations: Array<MatchV1.PlayerLocationsDto>;
        defuseLocation: MatchV1.LocationDto;
        playerStats: Array<MatchV1.PlayerRoundStatsDto>;
        roundResultCode: string;
    }
    interface MatchDto {
        matchInfo: MatchV1.MatchInfoDto;
        players: Array<MatchV1.PlayerDto>;
        coaches: Array<MatchV1.CoachDto>;
        teams: Array<MatchV1.TeamDto>;
        roundResults: Array<MatchV1.RoundResultDto>;
    }
    interface MatchlistEntryDto {
        matchId: string;
        gameStartTimeMillis: number;
        queueId: string;
        [key: string]: any;
    }
    interface MatchlistDto {
        puuid: string;
        history: Array<MatchV1.MatchlistEntryDto>;
        [key: string]: any;
    }
    interface RecentMatchesDto {
        currentTime: string;
        /**
         * A list of recent match ids.
         */
        matchIds: Array<string>;
        [key: string]: any;
    }
}
/**
 * ! This API service is required your project to be registered by Riot Games.
 */
export declare class MatchV1 extends RiotApiService {
    /**
     * Get match by id
     */
    byMatchId(matchId: string): Promise<AxiosResponse<MatchV1.MatchDto>>;
    /**
     * Get matchlist for games played by puuid
     */
    listByPuuid(puuid: string): Promise<AxiosResponse<MatchV1.MatchlistDto>>;
    /**
     * Get recent matches
     */
    recentByQueue(queueId: QueueId.ID): Promise<AxiosResponse<MatchV1.RecentMatchesDto>>;
}
